
# Slot: deprecated element has possible replacement


When an element is deprecated, it can be potentially replaced by this uri or curie

URI: [linkml:deprecated_element_has_possible_replacement](https://w3id.org/linkml/deprecated_element_has_possible_replacement)


## Domain and Range

None &#8594;  <sub>0..1</sub> uriorcurie

## Parents


## Children


## Used by

 * class_definition
 * common_metadata
 * definition
 * [Element](Element.md)
 * enum_definition
 * permissible_value
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | OIO:consider |

